/*! Copyright (c) 2002-2008 SAS Institute, Inc.  All rights reserved. */

/* ------------------------------------------------------------------------ *
 * Purpose: Contains the javascript classes and methods for the             *
 *          TimeStampPicker class     		                                *
 *                                                                          *
 *                                                                          *
 * ------------------------------------------------------------------------ */
// Client-side JavaScript for the TimeStampPicker tbean.
// 
// Author: anhill 04/13/06
sas.provides("sas_TimeStampPicker");
sas.requires("sas_dom");
openTimeStampSelectors= new Array;

function closeOpenTimeStampSelectors()
{
	for(var i=0;i<openTimeStampSelectors.length;i++)
	{
			openTimeStampSelectors[i].hideTime();
	}
}

function sas_TimeStampPicker_checkEscapeKey(event)
{
	if (!event) event=window.event;
	if(event.keyCode==27)
		closeOpenTimeStampSelectors();
}

function sas_TimeStampPicker_checkAltDownArrow(event, launchCommand)
{
	if (!event) event=window.event;
	if(event.keyCode==40)
	{
		if(event.altKey)
		{
			eval(launchCommand);
		}
		
	}
}

//sas_registerEventHandler(document,'click',closeOpenTimeStampSelectors,false);
sas_registerEventHandler(document,'keypress',sas_TimeStampPicker_checkEscapeKey, false);

// Creates a new TimePicker instance w/ the given name.
// @param name The name of the tbean and the prefix for its sub-components
function sas_TimeStampPicker(id)
{
	this.id	= id;	//used when referring to sub-components
	this.enabled=true;	
	this.launchImage='';
	this.launchImageDisabled='';
	this.comboComponent = null;
	this.timeComponent = null;
	this.nComponent = null;
	this.clockComponent = null;
	this.calendarComponent = null;
	this.nTimeLabel = null;
	this.initialNValue = null;	
	this.invalidValueMessage = "";
	this.yearsAgoErrorMessage = "";
	this.yearsFromNowErrorMessage = "";	
	this.amString;
	this.pmString;
	this.paletteCreated = false;	
	this.nValueIndex = 9;
    return this;
    
}
//sas_inherits(sas_TimeStampPicker, sas_TransformationBean);

// this is set as callback function on time component.
// when a time is selected from time selector it will forward a 
// call to this.
function sas_TimeStampPicker_setTextEntryToDateAndTime()
{
		this.hideNSelection();
		var timeStampObj = sas_getJavaScriptObject(this.id + "_TimeStamp"); //S0493843
		var calendarObj =this.calendarComponent; //S0493843
		var dateTimeTextualValue = (parseInt(calendarObj.selectedMonth, 10)+1)+"/"+calendarObj.selectedDate+"/"+calendarObj.selectedYear+" "+
			timeStampObj.getHours()+":"+timeStampObj.getMinutes()+":"+timeStampObj.getSeconds();
		if (timeStampObj.timeComponent.ampmComponent)
			dateTimeTextualValue += " "+timeStampObj.getAMPM(); //S0493843

		this.setFormattedTime(dateTimeTextualValue); //S0493843
}

function sas_TimeStampPicker_setInitialDateAndTime(_comboValue)
{
	var timePicker_nTimeLabel = document.getElementById(this.id+"_nTimeLabel");
		
	if(this.comboComponent.type == "text"){
		var textEntry =	this.comboComponent;
		textEntry.value=_comboValue;
	}
	else
	{
		var textEntry =	this.comboComponent;
		textEntry.setValue(_comboValue);
	}
		
	if(timePicker_nTimeLabel != null)
	{
		sas_TimeStampPicker_setNTimeLabelValues(timePicker_nTimeLabel, this.comboComponent.getSelectedIndex(), null, this.id);
		timePicker_nTimeLabel.style.visibility="visible";
		timePicker_nTimeLabel.style.display = "inline";
	}
	
		
}

// Receives an English datetime textual value formatted  according to the pattern "MM/dd/yyyy hh:mm:ss aaa",
// sends it to the server to receive back the localized version of that value to display to the user.
// see also com.sas.servlet.util.DateUtil.TIMESTAMP_PATTERN and com.sas.servlet.util.DateUtil.getLocalizedTimeStamp()
function sas_TimeStampPicker_setFormattedTime( dateTimeTextualValue) 
{
		var newTxt = dateTimeTextualValue.replace(/^\s+|\s+$/, '');  //Trim the trailing whitespace
		parms = {
			value : newTxt,
			METHOD : "getLocalizedTimeStamp"
	    };
	    var self = this;
 		function processReturnValues(type, data, xhr, options){
				eval(xhr.responseText);
								
				if(self.comboComponent.type == "text"){
					var textEntry =	self.comboComponent;
					textEntry.value=return_Obj.relativeString;
				}
				else
				{
					var textEntry =	self.comboComponent;
					textEntry.setValue(return_Obj.relativeString);
				}
				if (self.onChange != null)
					eval(self.onChange);
		}
		sas.ajax.send(this.url, parms, processReturnValues);
}

function sas_TimeStampPicker_setTime(hours, mins, secs, am_pm)
{
	if (this.clockComponent){
		this.clockComponent.setHours(parseInt(hours, 10));
		this.clockComponent.setMinutes(parseInt(mins, 10));
		this.clockComponent.setSeconds(parseInt(secs, 10));

		this.clockComponent.setAMPM(am_pm);
	}
	if (this.timeComponent){
		this.timeComponent.setHours(hours);
		this.timeComponent.setMinutes(mins);
		this.timeComponent.setSeconds(secs);
		this.timeComponent.setAMPM(am_pm);
	}
}

function sas_TimeStampPicker_showDialog()
{
	if(navigator.userAgent.toLowerCase().indexOf("macintosh") != -1)
	{		
		var clockDiv = document.getElementById("container_" + this.id+"_TimeStamp_Time");		
		var brObj = document.createElement("br");
		clockDiv.appendChild(brObj);
		var brObj2 = document.createElement("br");		
		clockDiv.appendChild(brObj2);			
	}
		
	var time = document.getElementById('time_'+this.id);
  	var iframe = document.getElementById("iframe_" + this.id);
	var image = document.getElementById(this.id+"_LaunchImage");
	
	// For defect S0377150.  Don't want popups to get clipped inside scrollable areas.
	// These popups all get written inline meaning they physically live in the DOM
	// whereever they get written. If thats in an overflow area then it will clip and
	// scroll accordingly.  To get it not to clip and scroll in these cases we would
	// need to write the popups outside the overflow areas (document.body).  Instead
	// of trying to rework these components to not be inline we are simply going to
	// relocate the dom nodes to document.body the first time they are displayed. This
	// will prevent them from affecting or being affected by overflow areas. Downside to this
	// is that if scrolling the overflow area the popups will not move with the item they
	// are attached to but this will be resolved with S0376349.
	if(time.parentNode!=document.body)
	{
		time = sas.dom.moveNode(time, document.body);
	  	if(iframe){
	  		iframe = sas.dom.moveNode(iframe, document.body);
	  	}
	}
	
	if(sas_isRTL())//S0704946
    {
		this.clockComponent.clockYPos = 85;
	  	this.clockComponent.clockXPos = 120;
	  	this.clockComponent.showClock(this.clockComponent.id);
		
		time.style.display='block'; 
		
		if (navigator.appName == 'Netscape')
	  	{
			//Needed to position the comboboxviews
 			this.timeComponent.hourComponent.positionIFrameCombo();
			this.timeComponent.minuteComponent.positionIFrameCombo();
			this.timeComponent.secondComponent.positionIFrameCombo();
		}
		
    }
	
	
	sas_autoPosition(time, document.getElementById("container_" + this.id))
	time.style.display='block';
	 
 	//Needed to position the comboboxviews 
	this.timeComponent.hourComponent.positionIFrameCombo();
	this.timeComponent.minuteComponent.positionIFrameCombo();
	this.timeComponent.secondComponent.positionIFrameCombo();
	 
	// so that palette sits on top of select form objects we
	// build an iframe that sits directly underneath our palette.
	if(iframe){
	 	sas_PositionNShowIframe(iframe,time);
	}
	image.style.position="relative";
	openTimeStampSelectors[openTimeStampSelectors.length]=this;
	var protectionAffectedObjects = [time,image]; 
	if(iframe){
		protectionAffectedObjects = [time,iframe,image]; 
	}
	sas_TimePicker_protectPage(true,"EXCLUSIVE",protectionAffectedObjects); 
	this.timeComponent.hourComponent.listBoxComponent.disabled=false;
	this.timeComponent.minuteComponent.listBoxComponent.disabled=false;
	this.timeComponent.secondComponent.listBoxComponent.disabled=false;
	if(this.timeComponent.ampmComponent != null)
		this.timeComponent.ampmComponent.disabled=false;
}
function sas_TimeStampPicker_showTime()
{
  var time = document.getElementById('time_'+this.id);
  // check and create iframe if and only if the browser is NOT FF and IE7
  if(xIE6){
  	var iframe = document.getElementById("iframe_" + this.id);
  	if(!iframe){
  		iframe = sas_createIframe(("iframe_" + this.id),3000,time.parentNode);
  	}
  }

  var selIndex = (this.comboComponent && this.comboComponent.getSelectedIndex) ? this.comboComponent.getSelectedIndex() : -1;
  var isRelative = false;
  if(selIndex >=0 && selIndex <= 12 && this.nTimeLabel){
		isRelative = true;  
		this.setTime(this.relativeHour, this.relativeMinute, this.relativeSeconds, this.relativeAM_PM)	
 		this.clockComponent.showClock(this.clockComponent.id);
		this.calendarComponent.setFormattedRelativeDate(this.relativeMonth,this.relativeDate, this.relativeYear);
  }

  var timeContainer = document.getElementById("fsContainer_"+this.timeComponent.id); 
  if (navigator.appName == 'Netscape')
  {
  	timeContainer.style.height="239px";
  	this.clockComponent.clockXPos = 420;
  	this.clockComponent.showClock(this.clockComponent.id);
  }
  else	 
  	timeContainer.style.height="241px";

  if (time.style.display == 'none')  
  {
	var parms = {
			 value : this.getValue(),
			 type : "TIMESTAMP",
			 METHOD : "parseDate"
			};	
	
	 var self = this;
	 function parseCallback(type, data, xhr, options){

		 eval(xhr.responseText);
		 if (return_Obj.error){
		 	if (selIndex == -1){
		 		alert(return_Obj.error);
				return;
			}
			else {
				self.setTime("12", "00", "00", self.amString);
				var today = new Date();
				self.calendarComponent.setFormattedRelativeDate(today.getMonth(),today.getDate(),today.getFullYear());
				self.showDialog();
				return;
			}
		 }
		 else{
		 	self.setTime(return_Obj.hour, return_Obj.minute, return_Obj.seconds, return_Obj.am_pm);
			self.clockComponent.showClock(self.clockComponent.id);
			self.calendarComponent.setFormattedRelativeDate(return_Obj.month,return_Obj.date,return_Obj.year);
			self.showDialog();
			return;
		 }
	 }
	 if (this.getValue() == ''){
	 	this.setTime("12", "00", "00", this.amString);
		var today = new Date();
		this.calendarComponent.setFormattedRelativeDate(today.getMonth(),today.getDate(),today.getFullYear());
		
	 	this.showDialog();
	 }
	 else if (isRelative){
	 	this.showDialog();
	 }else{
	 	sas.ajax.send(this.url, parms, parseCallback);	
	 }
  }
  return;
}


function sas_TimeStampPicker_hideTime()
{
  var paletteContainer = document.getElementById('paletteContainer_'+this.id);	
  var time = document.getElementById('time_'+this.id);
  var iframe = document.getElementById("iframe_" + this.id);
  var image = document.getElementById(this.id+"_LaunchImage"); 
  if(time.parentNode == document.body){
  	time = sas.dom.moveNode(time, paletteContainer);
	if(iframe){
	 		iframe = sas.dom.moveNode(iframe, paletteContainer);
	}
  }
      
  if (time.style.display == 'block'){
   	 time.style.display='none';
   	 if(iframe){
	   	 iframe.style.display='none';
   	 }
   	 image.style.position="";
	 var protectionAffectedObjects = [time,image]; 
   	 if(iframe){
	 	protectionAffectedObjects = [time,iframe,image]; 
	 }	 
 	 sas_TimePicker_protectPage(false,"EXCLUSIVE",protectionAffectedObjects); 
  }
  return;
}

function sas_TimeStampPicker_toggleTimeStampVisibility()
{

  /**  This is to display in a popup window
	var args = "width=280,"+
               "height=350,"+
               "toolbar=0,"+
               "menubar=0,"+
               "scrollbars=0,"+
               "resizable=1,"+
               "status=0,"+
               "location=0,"+
               "directories=0,"+
               "copyhistory=450";
    var subwindow = null;
    subwindow = sas_modalSelector_openModal("MethodInvocationServlet?CLASS_PARAMETER=com.sas.servlet.tbeans.html.TimePicker","subwin",args,1);

 **/

  if(!this.paletteCreated)
  {
  		var paletteContainer = document.getElementById('paletteContainer_'+this.id);
 		parms = {
				pickerid : this.id,
				METHOD : "createTimePickerPalette"
		    };
		    var self = this;
		    function palletteAjax(type, data, xhr, options){
		        //alert(xhr.responseText);
		        sas.ajax.replaceInnerHTML(paletteContainer, xhr.responseText);
		        //paletteContainer.innerHTML = xhr.responseText;
		        //eval(xhr.responseText);alert("after eval");
		        self.paletteCreated = true;
				  var time = document.getElementById('time_'+self.id);
				  if (time.style.display == 'none')  
				  {
					self.showTime();
				  }
				  else
				  {
				  	self.hideTime();	
				  }
				  return;
		    }
		    sas.ajax.send(this.palette_url, parms, palletteAjax);
  }
  else
  {
  	  var time = document.getElementById('time_'+this.id);
	  if (time.style.display == 'none')  
	  {
		this.showTime();
	  }
	  else
	  {
	  	this.hideTime();	
	  }
	  return;
  
  }
}

function sas_TimePicker_protectPage(protect,protectionType,protectionAffectedObjects) {
    if (!window.fastClickManager) {
        return;
    }
	if (protectionType)
		window.fastClickManager.setProtectionType(protectionType);
	if (protectionAffectedObjects)
    	 window.fastClickManager.setProtectionAffectedObjects(protectionAffectedObjects);
    if (protect) {
        if (window.fastClickManager.protectPage != null && typeof fastClickManager.protectPage == "function") {
            window.fastClickManager.protectPage();
        }
    } else {
        if (window.fastClickManager.unprotectPage != null && typeof window.fastClickManager.unprotectPage == "function") {
            window.fastClickManager.unprotectPage();
        }
    }
}

function sas_TimeStampPicker_enable()
{
	this.enabled=true;
	image = document.getElementById(this.id+"_LaunchImage");
	image.disabled=null;
	image.src=this.launchImage;		
	if(this.comboComponent.type == "text")
		this.comboComponent.disabled=null;
	else		
		this.comboComponent.setEnabled(true);
	
	if(this.nTimeLabel)
		this.nTimeLabel.disabled=null;
	
	if(this.nComponent)
		this.nComponent.disabled=null;

	comboLabel = document.getElementById(this.id+"_comboLabel");	
	if (comboLabel)
		comboLabel.disabled=null;			
		
}


function sas_TimeStampPicker_disable()
{
	this.enabled=false;	

	image = document.getElementById(this.id+"_LaunchImage");
	//image.src=this.launchImageDisabled;			
	image.disabled='DISABLED';

	if(this.comboComponent.type == "text")
		this.comboComponent.disabled='DISABLED';
	else
		this.comboComponent.setEnabled(false);
		
	if(this.nTimeLabel)
		this.nTimeLabel.disabled='DISABLED';
	if(this.nComponent)
		this.nComponent.disabled='DISABLED';

	comboLabel = document.getElementById(this.id+"_comboLabel");	
	if (comboLabel)
		comboLabel.disabled='DISABLED';
	
}

function sas_TimeStampPicker_setLaunchImage(launchImage)
{
	this.launchImage = launchImage;
}

function sas_TimeStampPicker_setLaunchImageDisabled(launchImageDisabled)
{
	this.launchImageDisabled = launchImageDisabled;
}

function sas_TimeStampPicker_setTimeComponent(timeComponent)
{

	if (timeComponent)
	{
		this.timeComponent = timeComponent;

	}
}

function sas_TimeStampPicker_setClockComponent(clockComponent)
{

	if (clockComponent)
	{
		this.clockComponent = clockComponent;
		this.clockComponent.parent = document.getElementById("time_"+this.id);
	}
}

function sas_TimeStampPicker_setCalendarComponent(calComponent)
{
	if (calComponent)
	{
		this.calendarComponent = calComponent;
	}
}

function sas_TimeStampPicker_setComboComponent(comboComponent)
{
	if (comboComponent)
	{
		this.comboComponent = comboComponent;
		//this.comboComponent.parentId = "time_"+this.id;
		
	}
}
sas_TimeStampPicker.prototype.validateNValue = function(obj) {
	var fireOnChange = false;
	if(obj.value && obj.value.length > 0)
	{
		var exprString = "^[0-9]{1,}$";
		if(!sas_isRegularExpressionValid(exprString, obj.value))
		{
			obj.value=1;
			sas_TimeStampPicker_updateNTimeLabel(this.nTimeLabel, this.comboComponent.id, this.nComponent.id, this.id);
			fireOnChange = true;			
		}
	}
	if( isNaN(obj.value) || !obj.value || obj.value.length == 0 ) {
		obj.value=1;
		sas_TimeStampPicker_updateNTimeLabel(this.nTimeLabel, this.comboComponent.id, this.nComponent.id, this.id);
		fireOnChange = true;		
	}
	if(fireOnChange)
	{
		if(this.onChange!=null)  eval(this.onChange);
	}	
}

sas_TimeStampPicker.prototype.keyPress = function(event) {
	if(!event)event=window.event;
	var exprString = "[0-9]";
	if(!sas_isKeyPressValid(event, exprString))
	{
		sas_stopOnKeyPress(event);
		return false;
	}

}

sas_TimeStampPicker.prototype.keyDown = function(event) {
	if (this.timerId) {
    	window.clearTimeout(this.timerId);
		if(!event)event=window.event;
		//check if tabKey is pressed and update the label
		if ( (sas_keyCode(event) == 9) || (xIE && sas_keyCode(event) == 13 ) ) {
			sas_TimeStampPicker_updateNTimeLabel(this.nTimeLabel, this.comboComponent.id, this.nComponent.id, this.id);
			this.validateNValue(this.nComponent);
			if(this.onChange!=null)  eval(this.onChange);
		}
		this.timerId = null;	
	}
}
sas_TimeStampPicker.prototype.keyUp = function(event) {
	var self = this;
	if (self.nComponent.value == "") {
		return;	
	}
	var timer = 500;
	if(!event)event=window.event;
	if (sas_keyCode(event) == 8) {
		timer = 1000; 
	}
	this.timerId = window.setTimeout(function() {
						sas_TimeStampPicker_updateNTimeLabel(self.nTimeLabel, self.comboComponent.id, self.nComponent.id, self.id);
						self.validateNValue(self.nComponent);
						if(self.fireOnChangeonKeyUp && self.onChange!=null )  {  
							eval(self.onChange);
						}
					}, timer); 
}


function sas_TimeStampPicker_setNComponent(nComponent)
{
	if (nComponent)
	{
		this.nComponent = nComponent;
		var pickerId = this.id;
		var comboId = this.comboComponent.id;
		var nComponentId = this.nComponent.id;
		var timeLabel = this.nTimeLabel;
		var onChange = this.onChange;
		var self = this;
		this.nComponent.onblur=function(event){self.validateNValue(this);}
		this.nComponent.onkeypress = function(event) { self.keyPress(event); }
		this.nComponent.onkeydown = function(event) { self.keyDown(event); }
		this.nComponent.onkeyup = function(event) { self.keyUp(event); }
		this.nComponent.onchange = function(event) { if (self.onChange != null) eval(self.onChange); }
	}
}

function sas_TimeStampPicker_updateNTimeLabel(nTimeLabel, comboComponent, nComponentId, pickerId)
{
	var comboIndex = sas_getJavaScriptObject(comboComponent).getSelectedIndex();
	var nComponent = document.getElementById(nComponentId);

	sas_TimeStampPicker_setNTimeLabelValues(nTimeLabel, comboIndex, nComponent.value, pickerId) ;
}

function sas_TimeStampPicker_setNTimeLabel(nLabelComponent)
{
	if (nLabelComponent)
	{
		this.nTimeLabel = nLabelComponent;
		sas_TimeStampPicker_setNTimeLabelValues(nLabelComponent, null, null, this.id)
	
	}
	this.nTimeLabel.style.visibility = "hidden";
}

function sas_TimeStampPicker_setNTimeLabelValues(nLabelComponent, comboSelectionIndex, nvalue, pickerId)
{
	if (nLabelComponent)
	{
		if (pickerId)
			var timePicker = sas_getJavaScriptObject(pickerId);
		if(timePicker)
			timePicker.nTimeLabel = nLabelComponent;
		if (comboSelectionIndex != null && comboSelectionIndex >= 0 && comboSelectionIndex <= timePicker.nValueIndex+3){
			if (comboSelectionIndex >= timePicker.nValueIndex){
				if (nvalue && !isNaN(nvalue)) //isNaN returns true if not numeric
				{
					nvalue = parseInt(nvalue, 10);
					var errorMessage = null;
					if (comboSelectionIndex == timePicker.nValueIndex && nvalue > 1752000){ //N hours ago
						errorMessage = timePicker.yearsAgoErrorMessage;
					}
					else if (comboSelectionIndex == timePicker.nValueIndex+1 && nvalue > 1752000){ //N hours from now
						errorMessage = timePicker.yearsFromNowErrorMessage;
					} 
					else if (comboSelectionIndex == timePicker.nValueIndex+2 && nvalue > 105120000){ //N minutes ago
						errorMessage = timePicker.yearsAgoErrorMessage;
					}
					else if (comboSelectionIndex == timePicker.nValueIndex+3 && nvalue > 105120000){ //N minutes from now
						errorMessage = timePicker.yearsFromNowErrorMessage;
					}
					if (errorMessage){
						var textEntry =	timePicker.comboComponent;
						var newTxtValue = textEntry.textComponent.value.replace(/^\w{1,}/, nvalue);
						if (timePicker.nComponent && timePicker.nComponent.style.display == 'inline'){
							alert(timePicker.invalidValueMessage + " " + newTxtValue + "\n" + errorMessage);
							timePicker.hideNSelection();
						}
						timePicker.comboComponent.setSelectedIndex(-1);
						return false;
					}
					
					if(timePicker.comboComponent.type == "text")
					{
						var textEntry =	timePicker.comboComponent;
						var newTxtValue = textEntry.value.replace(/^\w{1,}/, nvalue);
						textEntry.value = newTxtValue;
					}
					else
					{
						var textEntry =	timePicker.comboComponent;
						var newHidValue = textEntry.hiddenComponent.value.replace(/([N]|(\d{1,}))/, nvalue);
						textEntry.hiddenComponent.value = newHidValue;
					}
				}
				else{
					timePicker.nTimeLabel.innerHTML = '';
					return false;
				}
			}
			
			parms = {
				value : timePicker.getValue(),
				type : "TIMESTAMP",
				isRelative: true,
				METHOD : "parseDate"
		    };	
			sas.ajax.send(timePicker.url, parms, function(type, data, xhr, options){eval(xhr.responseText);
																					timePicker.nTimeLabel.innerHTML = '(' + return_Obj.relativeString + ')';
																					timePicker.relativeMonth = return_Obj.month;
																					timePicker.relativeDate = return_Obj.date;
																					timePicker.relativeYear = return_Obj.year;
																					timePicker.relativeHour = return_Obj.hour;
																					timePicker.relativeMinute = return_Obj.minute;
																					timePicker.relativeSeconds = return_Obj.seconds;
																					timePicker.relativeAM_PM = return_Obj.am_pm;});

		}
		else{
			timePicker.hideNSelection();
			timePicker.nTimeLabel.innerHTML = '';
		}
	}
}

function sas_TimeStampPicker_setValue(value)
{
	if(this.comboComponent.type == "text")
		var textEntry =	this.comboComponent;
	else
		var textEntry =	this.comboComponent.hiddenComponent;
	
	if(!value || value.length < 1)
	{
		textEntry.value="";
		if(this.comboComponent.type != "text")
			this.comboComponent.setSelectedIndex(-1);	
	}
	else
	{	
		textEntry.value=value;
		if(this.comboComponent.type != "text")
			this.comboComponent.setValue(value);	
	}
	if(this.comboComponent.type != "text")
		sas_TimeStampPicker_checkForNSelection(null, this.id, this.comboComponent.id);	
}

function sas_TimeStampPicker_getValue()
{
	//return an array object which contains the return value the selected item.

	var selectedValue = new Array();
	if(this.comboComponent.type == "text")
		var textEntry =	this.comboComponent;
	else
		var textEntry =	this.comboComponent.hiddenComponent;
	if (textEntry && textEntry.value != "")
		selectedValue[0] = textEntry.value;

	return selectedValue;

}

function sas_TimeStampPicker_setEnabled(state)
{
	if(state)
		this.enable();
	else
		this.disable();	
}

function sas_TimeStampPicker_showNSelection(_comboValue, _nTxtValue)
{
	var timePicker_nTimeLabel = document.getElementById(this.id+"_nTimeLabel");
	var timePicker_textEntry = document.getElementById(this.id+"_te");
	
	if(this.comboComponent.type == "text"){
		var textEntry =	this.comboComponent;
		textEntry.value=_comboValue;
	}
	else
	{
		var textEntry =	this.comboComponent;
		textEntry.setValue(_comboValue);
	}
		
	if(timePicker_textEntry != null) {
		timePicker_textEntry.style.display = "inline";
		timePicker_textEntry.value = _nTxtValue;
		timePicker_textEntry.select();
		timePicker_textEntry.focus();
			
	}
	if(timePicker_nTimeLabel != null)
	{
		sas_TimeStampPicker_setNTimeLabelValues(timePicker_nTimeLabel, this.comboComponent.getSelectedIndex(), _nTxtValue, this.id);
		timePicker_nTimeLabel.style.visibility="visible";
		timePicker_nTimeLabel.style.display = "inline";
	}
}

function sas_TimeStampPicker_hideNSelection()
{
	var timePicker_nTimeLabel = document.getElementById(this.id+"_nTimeLabel");
	var timePicker_textEntry = document.getElementById(this.id+"_te");

	if(timePicker_nTimeLabel != null && timePicker_nTimeLabel.style.visibility == "visible"){
		timePicker_nTimeLabel.style.visibility = "hidden";
		timePicker_nTimeLabel.style.display = "none";
	}

	if(timePicker_textEntry != null && timePicker_textEntry.style.display == "inline")
		timePicker_textEntry.style.display = "none";	
}

function sas_TimeStampPicker_checkForNSelection(event, _id, _comboId)
{
	if (!event) event=window.event;
//  S0500144 - Commenting out
//	
//	if(event)
//	{
//		var srcElement = sas_srcElement(event);
//		if(event && srcElement && srcElement.type == "text") 
//			return;
//	}

	var timePicker = sas_getJavaScriptObject(_id);
	var timePickerCombo = sas_getJavaScriptObject(_comboId);
	var isRelative = (timePickerCombo != null) ? true : false;
	if(!isRelative)
		return;
	var timePicker_nTimeLabel = document.getElementById(_id+"_nTimeLabel");
	var timePicker_textEntry = document.getElementById(_id+"_te");
	var timePicker_textEntry_cell = document.getElementById("nTextEntry_"+_id);
	var selectionIndex = timePickerCombo.getSelectedIndex();
	
	if (selectionIndex >= timePicker.nValueIndex && selectionIndex <= timePicker.nValueIndex+3)
	{		
		if(timePicker_textEntry != null)
		{
			if(timePicker_textEntry_cell != null)
				timePicker_textEntry_cell.className = "timeStampPickerNTextEntryCellPadding";
			timePicker_textEntry.style.display = "inline";
			timePicker_textEntry.value = timePicker.initialNValue;
			timePicker_textEntry.select();
			timePicker_textEntry.focus();
		}
	}
	else
	{
		if(timePicker_textEntry != null)
		{
			if(timePicker_textEntry_cell != null)
				timePicker_textEntry_cell.className = "timeStampPickerNTextEntryCellNoPadding";
			timePicker_textEntry.style.display = "none";
		}
	}

	if(timePicker_nTimeLabel != null)
	{
		sas_TimeStampPicker_setNTimeLabelValues(timePicker_nTimeLabel, selectionIndex, null, _id);
		timePicker_nTimeLabel.style.visibility = "visible";
		timePicker_nTimeLabel.style.display = "inline";
	}

}
function sas_TimeStampPicker_validateOnServer(callback) {
	parms = {
		value : this.getValue(),
		type : "TIMESTAMP",
		METHOD : "parseDate" 
	};
	sas.ajax.send(this.url, parms, callback);
}

function sas_TimeStampPicker_focus() {
	var textEntry = document.getElementById(this.id);
    if (!textEntry) textEntry = document.getElementById(this.id+"_combo_iFrameComboTEControl");
    	if(textEntry != null && textEntry.focus)
    	{
        	textEntry.focus();
    	}
}

sas_TimeStampPicker.prototype.toggleTimeStampVisibility = sas_TimeStampPicker_toggleTimeStampVisibility;
sas_TimeStampPicker.prototype.showTime = sas_TimeStampPicker_showTime;
sas_TimeStampPicker.prototype.showDialog = sas_TimeStampPicker_showDialog;
sas_TimeStampPicker.prototype.hideTime = sas_TimeStampPicker_hideTime;
sas_TimeStampPicker.prototype.setTextEntryToDateAndTime=sas_TimeStampPicker_setTextEntryToDateAndTime;
sas_TimeStampPicker.prototype.enable = sas_TimeStampPicker_enable;
sas_TimeStampPicker.prototype.disable = sas_TimeStampPicker_disable;
sas_TimeStampPicker.prototype.focus = sas_TimeStampPicker_focus;
sas_TimeStampPicker.prototype.setLaunchImageDisabled = sas_TimeStampPicker_setLaunchImageDisabled;
sas_TimeStampPicker.prototype.setLaunchImage = sas_TimeStampPicker_setLaunchImage;
sas_TimeStampPicker.prototype.setFormattedTime = sas_TimeStampPicker_setFormattedTime;
sas_TimeStampPicker.prototype.setTime = sas_TimeStampPicker_setTime;
sas_TimeStampPicker.prototype.setInitialDateAndTime = sas_TimeStampPicker_setInitialDateAndTime;
sas_TimeStampPicker.prototype.setValue = sas_TimeStampPicker_setValue;
sas_TimeStampPicker.prototype.getValue = sas_TimeStampPicker_getValue;
sas_TimeStampPicker.prototype.onChange = null;
sas_TimeStampPicker.prototype.setComboComponent = sas_TimeStampPicker_setComboComponent;
sas_TimeStampPicker.prototype.setNComponent = sas_TimeStampPicker_setNComponent;
sas_TimeStampPicker.prototype.setNTimeLabel = sas_TimeStampPicker_setNTimeLabel;
sas_TimeStampPicker.prototype.setTimeComponent = sas_TimeStampPicker_setTimeComponent;
sas_TimeStampPicker.prototype.setClockComponent = sas_TimeStampPicker_setClockComponent;
sas_TimeStampPicker.prototype.setCalendarComponent = sas_TimeStampPicker_setCalendarComponent;
sas_TimeStampPicker.prototype.hideNSelection = sas_TimeStampPicker_hideNSelection;
sas_TimeStampPicker.prototype.showNSelection = sas_TimeStampPicker_showNSelection;
sas_TimeStampPicker.prototype.setEnabled = sas_TimeStampPicker_setEnabled;
sas_TimeStampPicker.prototype.validateOnServer = sas_TimeStampPicker_validateOnServer;
